==> kubernetes-model-extensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/ReplicaSetConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ReplicaSetConditionBuilder extends ReplicaSetConditionFluentImpl<ReplicaSetConditionBuilder> implements VisitableBuilder<ReplicaSetCondition,ReplicaSetConditionBuilder>{
  public ReplicaSetConditionBuilder() {
    this(false);
  }
  public ReplicaSetConditionBuilder(Boolean validationEnabled) {
    this(new ReplicaSetCondition(), validationEnabled);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ReplicaSetCondition(), validationEnabled);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent,ReplicaSetCondition instance) {
    this(fluent, instance, false);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent,ReplicaSetCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ReplicaSetConditionBuilder(ReplicaSetCondition instance) {
    this(instance,false);
  }
  public ReplicaSetConditionBuilder(ReplicaSetCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ReplicaSetConditionFluent<?> fluent;
  Boolean validationEnabled;
  public ReplicaSetCondition build() {
    ReplicaSetCondition buildable = new ReplicaSetCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-extensions-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/ReplicaSetConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ReplicaSetConditionBuilder extends ReplicaSetConditionFluent<ReplicaSetConditionBuilder> implements VisitableBuilder<ReplicaSetCondition,ReplicaSetConditionBuilder>{
  public ReplicaSetConditionBuilder() {
    this(false);
  }
  public ReplicaSetConditionBuilder(Boolean validationEnabled) {
    this(new ReplicaSetCondition(), validationEnabled);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ReplicaSetCondition(), validationEnabled);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent,ReplicaSetCondition instance) {
    this(fluent, instance, false);
  }
  public ReplicaSetConditionBuilder(ReplicaSetConditionFluent<?> fluent,ReplicaSetCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ReplicaSetCondition());

    if (instance != null) {
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ReplicaSetConditionBuilder(ReplicaSetCondition instance) {
    this(instance,false);
  }
  public ReplicaSetConditionBuilder(ReplicaSetCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ReplicaSetCondition());

    if (instance != null) {
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ReplicaSetConditionFluent<?> fluent;
  Boolean validationEnabled;
  public ReplicaSetCondition build() {
    ReplicaSetCondition buildable = new ReplicaSetCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
